----------------------------------------------------------
--	Nog's Simple Crafting Tooltip
--		Simple AddOn to show your currently equipped
--			items in a tooltip window while crafting at
--			a smithing, woodworking, or clothier station
--	Copyright Nogaruk - 2014
----------------------------------------------------------

------------------------------
-- SETTINGS
------------------------------
local SVData
local SVDataDefaults =
{
	bShouldShowForEnchanting = false,
	defaultFont = "ZoFontWindowSubtitle",
	btnClickSound = "Click_MenuBar",
	textureDimX = 52,
	textureDimY = 52,
	dimConstraintX = 72,
	dimConstraintY = 472,
}
local SVDataProfile
------------------------------
-- VARIABLES
------------------------------
--	Chat message
local print = d
--	Window Manager
local wm = GetWindowManager()
--	Event Manager
local em = GetEventManager()
--	Reference to this addon for encapsulation
local _NSCT = ZO_Object:Subclass()
--	Main control window holder
local mcw
--	Button control window holder
local bcw
--	Button Array
local btnArrayHolder = {}
--	Tooltip control holder
local tooltipControl
--	Tooltip Icon holder
local tooltipIcon
--	Tooltip Fade holder
local tooltipFadeIconLeft, tooltipFadeIconRight
--	Tooltip Divider holder
local tooltipDivider
--	Settings holders - temporary
local defaultFont
local btnClickSound
local textureDimX
local textureDimY
local dimConstraintX
local dimConstraintY
local bShouldShowForEnchanting
local bSwitch = false

------------------------------
-- FUNCTIONS
------------------------------
	--New() - new function
		function _NSCT:New()
			self.addonName = "NSimpleCraftingTooltip"			
			--Initialization
			self:InitializeEventManagement()
		end
		
	--InitializeDefaults()
		function _NSCT:InitializeDefaults()
			defaultFont = SVDataDefaults.defaultFont
			btnClickSound = SVDataDefaults.btnClickSound
			textureDimX = SVDataDefaults.textureDimX
			textureDimY = SVDataDefaults.textureDimY
			dimConstraintX = SVDataDefaults.dimConstraintX
			dimConstraintY = SVDataDefaults.dimConstraintY
			bShouldShowForEnchanting = SVDataDefaults.bShouldShowForEnchanting
		end
		
	--Initialize()
		function _NSCT:Initialize()
			--	Set default parameters
			self:InitializeDefaults()
			
			--	Load in saved data if there is any
			if SVData then
				defaultFont = SVData.defaultFont
				btnClickSound = SVData.btnClickSound
				textureDimX = SVData.textureDimX
				textureDimY = SVData.textureDimY
				dimConstraintX = SVData.dimConstraintX
				dimConstraintY = SVData.dimConstraintY
				bShouldShowForEnchanting = SVData.bShouldShowForEnchanting
			end
		end
		
	--CreateControlWindow()
		function _NSCT:CreateControlWindow(controlWindowName,dimWidth,dimHeight,anchorSelfAlign,anchorParent,anchorTargetAlign,anchorOffsetX,anchorOffsetY)
			--	Holder variable
			local windowHolder = wm:CreateTopLevelWindow(controlWindowName)
			windowHolder:SetDimensions(dimWidth,dimHeight)
			windowHolder:ClearAnchors()
			windowHolder:SetAnchor(anchorSelfAlign, anchorParent, anchorTargetAlign, anchorOffsetX, anchorOffsetY)
			return windowHolder
		end

	--CreateControlButton()
		function _NSCT:CreateControlButton(btnName,btnParent,btnText,btnFont,btnSelfAlign,btnTargetAlign,btnOffsetX,btnOffsetY,btnDimX,btnDimY)
			--	Temp holder for button
			local btnHolder = wm:CreateControl(btnName,btnParent,CT_BUTTON)
			
			btnHolder:SetText(btnText)
			btnHolder:SetFont(btnFont)
			
			--	Font settings are not really needed atm, here in case of future features.
			--SetDisabledFontColor(number r, number g, number b, number a)
			btnHolder:SetDisabledFontColor(0,0,250,1)
			--SetDisabledPressedFontColor(number r, number g, number b, number a)
			btnHolder:SetDisabledPressedFontColor(0,250,250,1)
			--SetMouseOverFontColor(number r, number g, number b, number a)
			btnHolder:SetMouseOverFontColor(250,0,0,1)
			--SetNormalFontColor(number r, number g, number b, number a)
			btnHolder:SetNormalFontColor(0,250,0,1)
			--SetPressedFontColor(number r, number g, number b, number a)
			btnHolder:SetPressedFontColor(250,250,0,1)
			
			btnHolder:SetDimensions(btnDimX,btnDimY)
			btnHolder:SetAnchor(btnSelfAlign,btnParent,btnTargetAlign,btnOffsetX,btnOffsetY)
			
			btnHolder.tooltipText = "YO"
			
			--SetHandler(string handlerName, function functionRef)
			btnHolder:SetHandler("OnClicked", function(self) _NSCT:OnBtnClicked(btnHolder:GetName()) end)
			
			return btnHolder
		end
		
	--CreateButtonEquippedSlot()
		function _NSCT:CreateButtonEquippedSlot(btnName,slotName,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY,dimX,dimY)
				local btnHolder
				
				if slotName == "MainHand" then 
					--	Create the button control
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY,dimX,dimY)
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_2hsword_b.dds")
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_2hsword_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_mainhand.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "OffHand" then 
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY+dimY,dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_shield_b.dds")
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_shield_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_offhand.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "Head" then 
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY+(dimY*2),dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_heavy_head_b.dds")
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_heavy_head_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_head.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "Shoulder" then 
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY+(dimY*3),dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_heavy_shoulders_b.dds")
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_heavy_shoulders_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_shoulders.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "Chest" then 
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY+(dimY*4),dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_heavy_chest_b.dds")
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_heavy_chest_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_chest.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "Glove" then 
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY+(dimY*5),dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_heavy_hands_b.dds")
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_heavy_hands_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_hands.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "Belt" then 
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY+(dimY*6),dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_heavy_waist_b.dds")
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_heavy_waist_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_belt.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "Leg" then 
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY+(dimY*7),dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_heavy_legs_b.dds")
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_heavy_legs_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_legs.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "Foot" then 
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY+(dimY*8),dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/icons/gear_nord_heavy_feet_b.dds")
					btnHolder:SetMouseOverTexture("esoui/art/icons/gear_nord_heavy_feet_b.dds")
					btnHolder:SetNormalTexture("ESOUI/art/characterwindow/gearslot_feet.dds")
					btnHolder:SetClickSound("btnClickSound")
				elseif slotName == "Switch" then
					btnHolder = self:CreateControlButton(btnName,bcw,btnText,btnFont,selfAlign,targetAlign,offsetX,offsetY,dimX,dimY)
					btnHolder:SetPressedTexture("esoui/art/characterwindow/weaponswap_down.dds")
					btnHolder:SetMouseOverTexture("esoui/art/characterwindow/weaponswap_over.dds")
					btnHolder:SetNormalTexture("esoui/art/characterwindow/weaponswap_up.dds")
					btnHolder.tooltipText = "Swap which weapon set is shown"
				else
					--	do nothing
				end
				
				-- Place the button window into the holder array
				table.insert(btnArrayHolder, btnHolder)
			end
	
	--CreateTooltipWindow()
		function _NSCT:CreateTooltipWindow()
			if tooltipControl ~= nill then return 
			else
			
			--	TOOLTIP WINDOW CONTROL
			mcw = self:CreateControlWindow("NSCT_mcw_Base",0,0,TOPLEFT,GuiRoot,TOPLEFT,100,250)
			mcw:SetHidden(false)
			mcw:SetMovable(true)
			mcw:SetMouseEnabled(true)
			mcw:SetClampedToScreen(true)
			mcw:SetResizeToFitDescendents(true)
			mcw:SetHandler("OnReceiveDrag", function(self) self:StartMoving() end)
			mcw:SetHandler("OnMouseUp", function(self) self:StopMovingOrResizing() end)
			
			--	TOOLTIP BUTTON WINDOW CONTROL
			bcw = wm:CreateControl("NSCT_bcw_Base",mcw,CT_CONTROL)
			bcw:SetDimensionConstraints(-1,-1,dimConstraintX,dimConstraintY)
			bcw:SetResizeToFitDescendents(true)
			bcw:SetResizeToFitPadding(10,1)
			bcw:ClearAnchors()
			bcw:SetAnchor(TOPRIGHT,mcw,TOPLEFT,0,0)
			
			--	TOOLTIP BUTTON WINDOW BACKDROP
			bcw.bd = wm:CreateControlFromVirtual("NSCT_bcw_bd",bcw,"ZO_DefaultBackdrop")
			bcw.bd:SetAnchorFill(bcw)
			
			--	TOOLTIP BUTTONS
			self:CreateButtonEquippedSlot("btn_Switch","Switch",'',defaultFont,CENTER,TOPLEFT,-10,0,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_MainHand","MainHand",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_OffHand","OffHand",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_Head","Head",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_Shoulder","Shoulder",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_Chest","Chest",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_Glove","Glove",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_Belt","Belt",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_Leg","Leg",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			self:CreateButtonEquippedSlot("btn_Foot","Foot",'',defaultFont,TOPLEFT,TOPLEFT,5,2,textureDimX,textureDimY)
			
			--	TOOLTIP CONTROL
			tooltipControl = wm:CreateControl("NSCT_TooltipFrame",mcw,CT_TOOLTIP)
			tooltipControl:SetOwner(mcw,TOPLEFT,0,0,TOPLEFT)
			tooltipControl:SetDimensionConstraints(-1,-1,416,dimConstraintY)
			tooltipControl:SetResizeToFitPadding(32,57)
			tooltipControl:SetHeaderVerticalOffset(16)
			tooltipControl:SetWornItem(EQUIP_SLOT_MAIN_HAND)
			
			
			--	TOOLTIP BACKDROP
			tooltipControl.bd = wm:CreateControlFromVirtual(nil, tooltipControl, "ZO_DefaultBackdrop")
			tooltipControl.bd:SetAnchorFill(tooltipControl)
			
			--	TOOLTIP ICON
			tooltipIcon = wm:CreateControl("NSCT_TooltipIcon",tooltipControl,CT_TEXTURE)
			--	Check that there is something in the mainhand to pull the icon info from
			if (not ZO_CharacterEquipmentSlotsMainHandIcon:GetTextureInfo() or
				ZO_CharacterEquipmentSlotsMainHandIcon:GetTextureInfo() == "") then
				--	Nothing returned here so we'll set our missing item icon
				tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
			else
				--	It returned safely so we'll set the icon to what is there
				tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsMainHandIcon:GetTextureInfo())	
			end
			tooltipIcon:SetDimensions(64,64)
			tooltipIcon:ClearAnchors()
			tooltipIcon:SetAnchor(CENTER,tooltipControl,TOP,0,0)
			tooltipIcon:SetDrawLayer(3)
			tooltipIcon:SetDrawTier(2)
			
			--	TOOLTIP ICON FADE LEFT			
			tooltipFadeIconLeft = wm:CreateControl("NSCT_TooltipIconFadeLeft",tooltipControl,CT_TEXTURE)
			tooltipFadeIconLeft:SetTexture("ESOUI/art/itemtooltip/iconstrip.dds")
			tooltipFadeIconLeft:SetDimensions(100,4)
			--	SetTextureCoords(Left,Right,Top,Bottom) - setting left and bottom to 1 flips the image
			tooltipFadeIconLeft:SetTextureCoords(1,0,0,1)
			tooltipFadeIconLeft:ClearAnchors()
			tooltipFadeIconLeft:SetAnchor(TOPRIGHT,tooltipControl,TOP,0,0)
			tooltipFadeIconLeft:SetExcludeFromResizeToFitExtents(true)
			tooltipFadeIconLeft:SetDrawTier(2)
			
			--	TOOLTIP ICON FADE RIGHT
			tooltipFadeIconRight = wm:CreateControl("NSCT_TooltipIconFadeRight",tooltipControl,CT_TEXTURE)
			tooltipFadeIconRight:SetTexture("ESOUI/art/itemtooltip/iconstrip.dds")
			tooltipFadeIconRight:SetDimensions(100,4)
			tooltipFadeIconRight:ClearAnchors()
			tooltipFadeIconRight:SetAnchor(TOPLEFT,tooltipControl,TOP,0,0)
			tooltipFadeIconRight:SetExcludeFromResizeToFitExtents(true)
			tooltipFadeIconRight:SetDrawTier(2)
			
			--	TOOLTIP DIVIDER HEADER			
			tooltipDivider = wm:CreateControl("NSCT_TooltipDivider",tooltipControl,CT_TEXTURE)
			tooltipDivider:SetTexture("ESOUI/art/miscellaneous/horizontaldivider.dds")
			tooltipDivider:SetResizeToFitFile(true)
			tooltipDivider:ClearAnchors()
			tooltipDivider:SetAnchor(TOP,tooltipControl,TOP,0,88)
			
			--	TOOLTIP CHARGES BAR	-	TO-DO
			
			end
		end
		
	--ToggleEnchantingStation()
		local function ToggleEnchantingStation(boolValue)
			--	Lets make sure that regardless of what the user typed we make sure it is all lowercase
			boolValue = string.lower(boolValue)
			
			-- Check if any parameters were entered
			if (not boolValue or boolValue == "" or boolValue == "help") then
				--	Nothing was entered or "help" was used, so we should list out the command options
				print("Type '/nsct on' or '/nsct true' to show the tooltip window at the Enchanting station")
				print("Type '/nsct off' or '/nsct false' to hide the tooltip window at the Enchanting station")
			else
				print("Turning tooltip window " .. string.upper(boolValue) .. " for Enchanting station")

				if boolValue == "on" or boolValue == "true" then
					bShouldShowForEnchanting = true
				elseif boolValue == "off" or boolValue == "false" then
					bShouldShowForEnchanting = false
				else return end
			
				SVData.bShouldShowForEnchanting = bShouldShowForEnchanting
			end
		end
------------------------------
-- EVENTS
------------------------------
	--InitializeEventManagement() - initialize events function
		function _NSCT:InitializeEventManagement()
			--	Register Handlers for Event actions
			em:RegisterForEvent(self.addonName.."_OnAddonLoaded",EVENT_ADD_ON_LOADED, function(...) self:OnAddonLoaded(...) end)
			em:RegisterForEvent(self.addonName.."_OnPlayerActivated", EVENT_PLAYER_ACTIVATED, function(...) self:OnPlayerActivated(...) end)
			em:RegisterForEvent(self.addonName.."_OnStationInteract", EVENT_CRAFTING_STATION_INTERACT, function(...) self:OnStationInteract(...) end)
			em:RegisterForEvent(self.addonName.."_OnStationInteractEnd", EVENT_END_CRAFTING_STATION_INTERACT, function(...) self:OnStationInteractEnd(...) end)
		end
		
	--OnAddonLoaded()
		function _NSCT:OnAddonLoaded(eventCode, addonName)
			if(addonName == self.addonName) then
				--	Create the saved variable
				SVData = ZO_SavedVars:NewAccountWide("NSCT_Saves", 1, nil, SVDataDefaults)
			end
			--	Setup slash commands
			SLASH_COMMANDS["/nsct"] = ToggleEnchantingStation
		end
	
	--OnPlayerActivated()
		function _NSCT:OnPlayerActivated()
			self:Initialize()
		end
		
	--OnStationInteract() - Event handler for when you start interacting (open) with a crafting station
		function _NSCT:OnStationInteract()
			local CraftingType = GetCraftingInteractionType()
			if CraftingType == CRAFTING_TYPE_BLACKSMITHING or
				CraftingType == CRAFTING_TYPE_CLOTHIER or CraftingType == CRAFTING_TYPE_WOODWORKING 
				or (CraftingType == CRAFTING_TYPE_ENCHANTING and bShouldShowForEnchanting) then 
				if mcw ~= nil then
					mcw:SetHidden(false)
				else
					self:CreateTooltipWindow()
				end
			else return end
		end
		
	--OnStationInteractEnd() - Event handler for when you stop interacting (close) with a crafting station
		function _NSCT:OnStationInteractEnd()
			if mcw ~= nil then
				mcw:SetHidden(true)
			else end
		end
		
	--OnBtnClicked() - Event handler for when you click one of the equipment slot buttons
	--	@param buttonName - string variable used to find what button is being clicked at the moment
		function _NSCT:OnBtnClicked(buttonName)
			local tempTextureHolder
			
			if buttonName == "btn_Switch" then
				bSwitch = not bSwitch
				self:OnBtnClicked("btn_MainHand")
			elseif buttonName == "btn_MainHand" then
				tooltipControl:ClearLines()
				if bSwitch then
					tooltipControl:SetWornItem(EQUIP_SLOT_BACKUP_MAIN)
					tempTextureHolder = ZO_CharacterEquipmentSlotsBackupMainIcon:GetTextureInfo()
					if ( not tempTextureHolder or tempTextureHolder == "" ) then
						tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
					else
						tooltipIcon:SetTexture(tempTextureHolder)
					end
				else
					tooltipControl:SetWornItem(EQUIP_SLOT_MAIN_HAND)
					tempTextureHolder = ZO_CharacterEquipmentSlotsMainHandIcon:GetTextureInfo()
					if ( not tempTextureHolder or tempTextureHolder == "" ) then
						tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
					else
						tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsMainHandIcon:GetTextureInfo())
					end
				end
			elseif buttonName == "btn_OffHand" then
				tooltipControl:ClearLines()
				if bSwitch then
					tooltipControl:SetWornItem(EQUIP_SLOT_BACKUP_OFF)
					tempTextureHolder = ZO_CharacterEquipmentSlotsBackupOffIcon:GetTextureInfo()
					if ( not tempTextureHolder or tempTextureHolder == "" ) then
						tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
					else
						tooltipIcon:SetTexture(tempTextureHolder)
					end
				else
					tooltipControl:SetWornItem(EQUIP_SLOT_OFF_HAND)
					tempTextureHolder = ZO_CharacterEquipmentSlotsOffHandIcon:GetTextureInfo()
					if ( not tempTextureHolder or tempTextureHolder == "" ) then
						tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
					else
						tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsOffHandIcon:GetTextureInfo())
					end
				end
			elseif buttonName == "btn_Head" then
				tooltipControl:ClearLines()
				tooltipControl:SetWornItem(EQUIP_SLOT_HEAD)
				tempTextureHolder = ZO_CharacterEquipmentSlotsHeadIcon:GetTextureInfo()
				if ( not tempTextureHolder or tempTextureHolder == "" ) then
					tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
				else
					tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsHeadIcon:GetTextureInfo())
				end
			elseif buttonName == "btn_Shoulder" then
				tooltipControl:ClearLines()
				tooltipControl:SetWornItem(EQUIP_SLOT_SHOULDERS)
				tempTextureHolder = ZO_CharacterEquipmentSlotsShoulderIcon:GetTextureInfo()
				if ( not tempTextureHolder or tempTextureHolder == "" ) then
					tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
				else
					tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsShoulderIcon:GetTextureInfo())
				end
			elseif buttonName == "btn_Chest" then
				tooltipControl:ClearLines()
				tooltipControl:SetWornItem(EQUIP_SLOT_CHEST)
				tempTextureHolder = ZO_CharacterEquipmentSlotsChestIcon:GetTextureInfo()
				if ( not tempTextureHolder or tempTextureHolder == "" ) then
					tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
				else
					tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsChestIcon:GetTextureInfo())
				end
			elseif buttonName == "btn_Glove" then
				tooltipControl:ClearLines()
				tooltipControl:SetWornItem(EQUIP_SLOT_HAND)
				tempTextureHolder = ZO_CharacterEquipmentSlotsGloveIcon:GetTextureInfo()
				if ( not tempTextureHolder or tempTextureHolder == "" ) then
					tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
				else
					tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsGloveIcon:GetTextureInfo())
				end
			elseif buttonName == "btn_Belt" then
				tooltipControl:ClearLines()
				tooltipControl:SetWornItem(EQUIP_SLOT_WAIST)
				tempTextureHolder = ZO_CharacterEquipmentSlotsBeltIcon:GetTextureInfo()
				if ( not tempTextureHolder or tempTextureHolder == "" ) then
					tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
				else
					tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsBeltIcon:GetTextureInfo())
				end
			elseif buttonName == "btn_Leg" then
				tooltipControl:ClearLines()
				tooltipControl:SetWornItem(EQUIP_SLOT_LEGS)
				tempTextureHolder = ZO_CharacterEquipmentSlotsLegIcon:GetTextureInfo()
				if ( not tempTextureHolder or tempTextureHolder == "" ) then
					tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
				else
					tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsLegIcon:GetTextureInfo())
				end
			elseif buttonName == "btn_Foot" then
				tooltipControl:ClearLines()
				tooltipControl:SetWornItem(EQUIP_SLOT_FEET)
				tempTextureHolder = ZO_CharacterEquipmentSlotsFootIcon:GetTextureInfo()
				if ( not tempTextureHolder or tempTextureHolder == "" ) then
					tooltipIcon:SetTexture("/esoui/art/icons/icon_missing.dds")
				else
					tooltipIcon:SetTexture(ZO_CharacterEquipmentSlotsFootIcon:GetTextureInfo())
				end
			else return end
		end
------------------------------
-- CALL
------------------------------
	-- Create the main window
		_NSCT:New()

		
		
------------------------------
-- CHANGE LOG
------------------------------
--[[
--	Version 0.3 
	-	Added the ability to swap which weapon set the main hand and off hand will pull data from
--	Version 0.2b
	-	Functionality update
	-		Add ability to show in Enchanting station
	-		Added slash command to toggle Enchanting station window
	-		Added slash command for "help" to show slash command listings
	-		Added save file to store Enchanting station options across all characters
	
--	Version 0.2a
	-	Error update
	-		Fixed README file showing up in menu
	-		Fixed the window not disapearing when leaving a station
	
--	Version 0.2
	-	Graphics update
	-		Changed base icons for equipment slot selection
	-		Added mouseover and pressed icons for equipment selection
	-		Added error checking for icon graphics
	-		Added tint graphic behind the currently selected equipment icon
	-		Added divider bar between header text
	
--	Version 0.1
	-	Base version launched
]]